# Copyright 2014  Lars Wirzenius
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# =*= License: GPL-3+ =*=


import contextlib
import errno
import StringIO
import unittest

import distixlib


class MetadataSaverTests(unittest.TestCase):

    def test_raises_specific_error_when_open_fails(self):

        def raise_ioerror(*args):
            raise IOError(errno.EROFS, 'rofs', 'filename')

        saver = distixlib.MetadataSaver()
        saver._open_file = raise_ioerror
        self.assertRaises(
            distixlib.CannotSaveMetadataError,
            saver.save_to_file,
            'my-filename',
            distixlib.Metadata())

    def test_saves_to_file(self):

        f = StringIO.StringIO()
        f.close = lambda: None

        def capture_text(*args):
            return contextlib.closing(f)

        metadata = distixlib.Metadata()
        metadata.add('key', 'value')

        saver = distixlib.MetadataSaver()
        saver._open_file = capture_text
        saver.save_to_file('foobar', metadata)

        self.assertEqual(f.getvalue(), 'key:\n- value\n')
