# Copyright 2014  Lars Wirzenius
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# =*= License: GPL-3+ =*=


import email
import glob
import locale
import os
import time

import cliapp

import distixlib


class ListPlugin(cliapp.Plugin):

    def enable(self):
        self.app.add_subcommand(
            'list', self.list, arg_synopsis='')

    def list(self, args):
        '''List tickets.'''

        repo = distixlib.Repository('.')
        ticket_store = repo.open_ticket_store(distixlib.tickets_dir_name)
        all_tickets = ticket_store.get_tickets()

        if len(args) == 1:
            tickets_to_list = self._select_tickets(all_tickets, args[0])
        else:
            tickets_to_list = all_tickets
        tickets_to_list = self._sort_tickets(tickets_to_list)

        variables = {
            'tickets': tickets_to_list,
        }

        renderer = self._get_renderer()
        text = renderer.render('list.j2', variables)
        self.app.output.write(text)

    def _select_tickets(self, tickets, pattern):
        key, value = self._parse_pattern(pattern)
        return [
            ticket
            for ticket in tickets
            if not self._has_key_value_pair(ticket, key, value)]

    def _parse_pattern(self, pattern):
        if '!=' in pattern:
            return pattern.split('!=', 1)
        else:
            return None, None

    def _has_key_value_pair(self, ticket, key, value):
        metadata = ticket.get_ticket_metadata()
        return key in metadata and value in metadata.get_all_values(key)

    def _sort_tickets(self, tickets):
        return sorted(tickets, key=lambda t: t.get_newest_message_timestamp())

    def _get_renderer(self):
        _, encoding = locale.getdefaultlocale()
        if encoding is None:
            encoding = 'UTF8'

        renderer = distixlib.TextRenderer()
        renderer.set_output_encoding(encoding)
        return renderer
