# Copyright 2014  Lars Wirzenius
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# =*= License: GPL-3+ =*=


import contextlib
import email.mime.multipart
import email.mime.text
import mailbox
import os

import cliapp

import distixlib


class ReplyPlugin(cliapp.Plugin):

    _commit_msg = 'new reply'

    def enable(self):
        self.app.add_subcommand(
            'reply', self.reply, arg_synopsis='TICKETID')

        self.app.settings.string(
            ['message', 'm'],
            'use MSG as the message body of the reply',
            metavar='MSG')

    def reply(self, args):
        '''Add a reply message to a ticket.'''

        self.app.settings.require('message')

        repo = distixlib.Repository('.')
        repo.require_clean_working_tree()
        ticket_store = repo.open_ticket_store(distixlib.tickets_dir_name)
        ticket_id = distixlib.get_ticket_ids(self.app.settings, args)[0]
        ticket = ticket_store.get_ticket(ticket_id)

        message_body = self._get_message_body()
        email_msg = self._create_reply(ticket, message_body)
        ticket.add_message(email_msg)

        filenames = ticket_store.save_changes()
        repo.commit_changes(filenames, self._commit_msg)

    def _get_message_body(self):
        return self.app.settings['message']

    def _create_reply(self, ticket, message_body):
        msg = email.mime.text.MIMEText(message_body, _charset='utf-8')
        msg['From'] = 'Tomjon'
        msg['Subject'] = 'Re: %s' % ticket.get_title()
        return msg
