# Copyright 2016  Lars Wirzenius
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# =*= License: GPL-3+ =*=


import unittest

import distixlib


class TextRendererTests(unittest.TestCase):

    def test_renders_empty_template_to_empty_output(self):
        renderer = distixlib.TextRenderer()
        renderer.set_output_encoding('us-ascii')
        output = renderer.render('empty.j2', {})
        self.assertEqual(output, '')

    def test_renders_usascii_template_to_usascii_output(self):
        renderer = distixlib.TextRenderer()
        renderer.set_output_encoding('us-ascii')
        output = renderer.render('ascii.j2', {})
        self.assertEqual(output, 'just ascii, please')

    def test_renders_non_ascii_template_to_usascii_output(self):
        renderer = distixlib.TextRenderer()
        renderer.set_output_encoding('us-ascii')
        output = renderer.render('unicode.j2', {})
        self.assertEqual(output, 'porridge, grt')

    def test_renders_non_ascii_template_to_utf8_output(self):
        renderer = distixlib.TextRenderer()
        renderer.set_output_encoding('utf8')
        output = renderer.render('unicode.j2', {})
        self.assertEqual(output, u'porridge, gr\u00f6t'.encode('utf8'))
